#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pantry
version:              0.8.3
visibility:           public
id:                   pantry-0.8.3-FupMFvNCmc13rsxEcSSBVL
key:                  pantry-0.8.3-FupMFvNCmc13rsxEcSSBVL
license:              BSD-3-Clause
copyright:            2018-2022 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/pantry#readme
synopsis:             Content addressable Haskell package management
description:
    Please see the README on GitHub at <https://github.com/commercialhaskell/pantry#readme>

category:             Development
abi:                  022d61299ff693695098600d1a083a04
exposed:              True
exposed-modules:
    Pantry Pantry.Internal Pantry.Internal.AesonExtended
    Pantry.Internal.Companion Pantry.Internal.Stackage
    Pantry.Internal.StaticBytes Pantry.SHA256

hidden-modules:
    Hackage.Security.Client.Repository.HttpLib.HttpClient
    Pantry.Archive Pantry.HTTP Pantry.HPack Pantry.Hackage Pantry.Repo
    Pantry.SQLite Pantry.Storage Pantry.Casa Pantry.Tree Pantry.Types
    System.IsWindows

import-dirs:          /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pantry
hs-libraries:         HSpantry-0.8.3-FupMFvNCmc13rsxEcSSBVL
depends:
    Cabal-3.10.3.0 aeson-2.2.2.0-E8GnKqfyoqV8B1evVkUtMu
    ansi-terminal-1.1-7dL9hv2pnhf1UozNlva3HX base-4.18.2.1
    bytestring-0.11.5.3 casa-client-0.0.3-24VMEZeemMaLyDJXfh7Ube
    casa-types-0.0.3-LUg7zKTP4xkLhru6eB8VUt
    conduit-1.3.6.1-2TgBnHtxRcL45MnFdbw3BB
    conduit-extra-1.3.8-IMQsosV8b6Ffbob12dcl9 containers-0.6.7
    crypton-1.0.4-HC713on0Tm0Jjrcsma8Kfd
    crypton-conduit-0.2.3-5lHwBpe8Wy46PpwFYu8yVK
    digest-0.0.2.1-JWOwjMkQwx5F9nVaVojfVV
    filelock-0.1.1.8-5QxiVKm9NGHIqrshtpQCkf
    generic-deriving-1.14.7-HdLJPkscNpb4ZdudsqYE85
    hackage-security-0.6.3.2-IUS4KLoBFpBGvzqcY3yoPa
    hpack-0.38.0-1xrX6NOGAv7ALmz9P6m29t
    http-client-0.7.19-7npayQWK93786YkcsXS9Bz
    http-client-tls-0.3.6.4-AoMgZkRCYiu1L0w7n4Ap42
    http-conduit-2.3.9.1-3odMc7W2YAgKcJourW85FN
    http-download-0.2.1.0-61D4LYvnwWEFfST5ygRyZ3
    http-types-0.12.4-DdbAmHNhx8C4vBT5NO2sZU
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5 mtl-2.3.1
    network-uri-2.6.4.2-2ifukYXf4pdA7CoyyYtsZ3
    path-0.9.6-KynYwMYg66BEQLxNIRjxgo
    path-io-1.8.2-DPRsMC3UxacFS7llYiYGfj
    persistent-2.14.5.2-70KhJcDJThu6nhKQsbrhT6
    persistent-sqlite-2.13.2.0-HYF6rFblqGF501hDjc1syL
    primitive-0.9.1.0-BBFYMlEh4bp124N2egPDqe
    resourcet-1.2.6-1nkc80Rj0478ycxyUoAOs8
    rio-0.1.24.0-JkwqYIu0JXwGTNiCUtqCtk
    rio-orphans-0.1.2.0-1IVkECMaqQt7JmsAeyLUei
    rio-prettyprint-0.1.8.0-KPLWbGDUqxb9LOlrOXfLRO
    tar-conduit-0.4.1-D3IRKkOdxO99WrD7bw0oED text-2.0.2
    text-metrics-0.3.3-JtJR7qU6sNN6grXJrlafl7 time-1.12.2
    transformers-0.6.1.0 unix-compat-0.7.4.1-BgJ7k18eSblG26Jg0cNHuH
    unliftio-0.2.25.1-406ICvddDrs4REwMxxdvSj
    unordered-containers-0.2.20.1-FX7g4DMKoiaDV91wUmRzTu
    vector-0.13.2.0-E81GJWrGuCo4SgJOIsfBQo
    yaml-0.11.11.2-522eVvWeGWK8ZJNXHI0ArS
    zip-archive-0.4.3.2-GdVQEP7gOHgG7qmIITbG0R

haddock-interfaces:   /usr/share/doc/haskell-pantry/html/pantry.haddock
haddock-html:         /usr/share/doc/haskell-pantry/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

